﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub HP 8566B/68B Take Sweep Only
INSTRUMENT:            Sub HP 8566B/68B Take Sweep (MKF)
INSTRUMENT:            Sub HP 8566B/68B Take Sweep (MKPK)
INSTRUMENT:            Sub HP 8566B/68B Take Sweep (MKPK, MKCF)
INSTRUMENT:            Sub HP 8566B/68B Command Complete
INSTRUMENT:            Sub HP 8566B/68B Error Query
DATE:                  2009-04-23
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       6
NUMBER OF LINES:       261
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        8566B, 8568B
#
#  Compatibility:
#        MET/CAL 7.20 SP1 (7.20x) or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
#  From HP/Agilent 856x and 859x programming manuals:
#
#   Take Sweep
#
#       (TS)------->(;)----------------------->
#             .....>(carriage return).....
#             .....>(line-feed)...........
#             .....>(space)...............
#             .....>(,)...................
#
#       The solid line (semicolon) is the preferred syntax.
#
#   Note from the syntax diagram a terminator is required.
#
#   The manual also states the following:
#
#   "When the analyzer receives a TS command, it is not ready
#   to receive any more data via HP-IB until one full sweep
#   had been completed."
#
#   The following, however, has been confirmed by Agilent:
#
#   The 856xE and 856xE/EC series analyzers start the sweep when
#   the terminator is received, as documented.  All other models,
#   however, start the sweep when the 'S' (in "TS") is received.
#   Therefore, since the analyzer cannot process other commands
#   while the sweep is in progress, the following programming is
#   used:
#
#   856xA (except 8566A & 8568A), 856xB, and all 8590's:
#
#     "TS"
#
#     If "TS;" is sent to a 856xA, 856xB, or 8590, the sweep will
#     start when the 'S' is received.  The 856x driver then hangs
#     on the IEEE-488 write until the sweep completes instead of
#     dropping into it's "wait for end of sweep SRQ" loop. The
#     result is a IEEE-488 timeout if the sweep time is longer
#     than the IEEE-488 timeout specified.
#
#   856xE and 856xE/EC:
#
#     "TS;"
#
#     If the "TS" command (with no terminator) is sent to a 856xE
#     or 856xE/EC, error 111 is be generated.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Initialize error variable.
  1.001  MATH         Error = 0
# Set number of sweeps in variable Sweeps.
  1.002  MATH         Sweeps = 2

  1.003  JMPL         ONLY                         PSUBI("Only")
  1.004  JMPL         MKF                          PSUBI("(MKF)")
  1.005  JMPL         MKPK                         PSUBI("(MKPK)")
  1.006  JMPL         MKPK_MKCF                    PSUBI("(MKPK, MKCF)")
  1.007  JMPL         COMMAND_COMPLETE             PSUBI("Complete")
  1.008  JMPL         ERROR_QUERY                  PSUBI("Error")
  1.009  DISP         Called subprocedure not found!
  1.010  END

# ====== Sub HP 8566B/68B Take Sweep Only ==================================
#
# This sub takes two sweeps and does not alter the marker, center frequency,
# or any other UUT settings.
#
#  Example:
# 1.001  CALL         Sub HP 8566B/68B Take Sweep Only

  1.011  LABEL        ONLY

  1.012  WHILE        Sweeps > 0
# Enable pertinent SRQ bits, take sweep, wait for 'end of sweep' SRQ.
  1.013  IEEE         [SPL]RQS 36;TS[SRQ 360000]
  1.014  CALL         Sub HP 8566B/68B Error Query
# Decrement sweep counter by one.
  1.015  MATH         Sweeps = Sweeps - 1
  1.016  ENDW

  1.017  END

  1.018  EVAL   Increment Step Number

# ====== Sub HP 8566B/68B Take Sweep (MKF) =================================
#
# This sub takes two sweeps, placing the active marker at a frequency passed
# by the calling procedure after the second sweep.
#
#  Example:
# 1.001  MATH         @MkrFreq = 1E+6
# 1.002  CALL         Sub HP 8566B/68B Take Sweep (MKF)

  2.001  LABEL        MKF

  2.002  WHILE        Sweeps > 0
  2.003  IEEE         [SPL]RQS 46;TS[SRQ 60000, 4]
  2.004  CALL         Sub HP 8566B/68B Error Query
# Decrement sweep counter by one.
  2.005  MATH         Sweeps = Sweeps - 1
  2.006  ENDW

# Set UUT marker to specified (in @MkrFreq) frequency in Hertz.
  2.007  IEEE         MKF [V @MkrFreq]HZ;

  2.008  END

  2.009  EVAL   Increment Step Number

# ====== Sub HP 8566B/68B Take Sweep (MKPK) ================================
#
# This sub takes two sweeps, placing the active marker at the highest peak
# present on the display after each sweep. Note that the active marker may
# be the "delta" marker, if previously specified in the calling procedure.
#
#  Examples:
# 1.001  CALL         Sub HP 8566B/68B Take Sweep (MKPK)
#
# 1.002  IEEE         MKD;
# 1.003  CALL         Sub HP 8566B/68B Take Sweep (MKPK)

  3.001  LABEL        MKPK

  3.002  WHILE        Sweeps > 0
  3.003  IEEE         [SPL]RQS 46;TS[SRQ 60000, 4]
  3.004  CALL         Sub HP 8566B/68B Error Query
# Set UUT marker to (highest) peak.
  3.005  IEEE         MKPK HI;
  3.006  MATH         Sweeps = Sweeps - 1
  3.007  ENDW

  3.008  END

  3.009  EVAL   Increment Step Number

# ====== Sub HP 8566B/68B Take Sweep (MKPK, MKCF) ==========================
#
# This sub takes two sweeps, placing the active marker at the highest peak
# present on the display, then moving the marker to the center frequency after
# each sweep. Note that the active marker may be the "delta" marker, if
# specified previously in the calling procedure.
#
#  Example:
# 1.001  CALL         Sub HP 8566B/68B Take Sweep (MKPK, MKCF)
#
# 1.002  IEEE         MKD;
# 1.003  CALL         Sub HP 8566B/68B Take Sweep (MKPK)
#
# Note that this sub does NOT turn the UUT signal tracking on; that must be
# done explicitly, if desired. In that case, it is preferred to accomplish
# the task as follows:
#
# 1.001  MATH         @Cmd = "MKTRACK ON;"
# 1.002  CALL         Sub HP 8566B/68B Command Complete
# 1.003  CALL         Sub HP 8566B/68B Take Sweep (MKPK, MKCF)
#
# Turning signal tracking on will automatically place the marker at the UUT
# center frequency, in addition to keeping it there if the UUT/source drifts.

  4.001  LABEL        MKPK_MKCF

  4.002  WHILE        Sweeps > 0
  4.003  IEEE         [SPL]RQS 46;TS[SRQ 60000, 4]
  4.004  CALL         Sub HP 8566B/68B Error Query
# Set UUT marker to (highest) peak; move marker to center frequency.
  4.005  IEEE         MKPK HI;MKCF;
  4.006  MATH         Sweeps = Sweeps - 1
  4.007  ENDW

  4.008  END

  4.009  EVAL   Increment Step Number

# ====== Sub HP 8566B/68B Command Complete =================================
#
# This sub waits for the sent command string to finish prior to proceeding.
#
#  Example:
# 1.001  MATH         @Cmd = "SNGLS;CF 300MZ;SP 10MZ;RL -20DB;AT 0DB;"
# 1.002  CALL         Sub HP 8566B/68B Command Complete

  5.001  LABEL        COMMAND_COMPLETE
  5.002  IEEE         [T60000][V @Cmd];DONE;[I!]
  5.003  END

  5.004  EVAL   Increment Step Number

# ====== Sub HP 8566B/68B Error Query ======================================
#
# If an error is reported by the UUT, this sub queries the error queue until
# they are all read and reported to the operator.
#
# HP 8566B/8568B SRQ Error Codes
#
#        Bit 0 - "1" Not Used
#        Bit 1 - "2" Frequency Limit Exceeded
#        Bit 2 - "4" End of Sweep
#        Bit 3 - "8" Hardware Broken
#        Bit 4 - "16" Not Used
#        Bit 5 - "32" Command Error

  6.001  LABEL        ERROR_QUERY

  6.002  IF           BIT(1, MEM)
  6.003  DISP         UUT Frequency Limit Exceeded!
  6.004  MATH         MEM1 = -1
  6.005  ELSEIF       BIT(3, MEM)
  6.006  DISP         UUT Hardware Broken!
  6.007  MATH         MEM1 = -1
  6.008  ELSEIF       BIT(5, MEM)
  6.009  DISP         UUT Command Error!
  6.010  MATH         MEM1 = -1
  6.011  ELSEIF       BIT(2, MEM)
  6.012  MATH         MEM1 = 1
  6.013  ELSE
  6.014  DISP         Unidentified SRQ from UUT!
  6.015  ENDIF

  6.016  IEEE         RQS 0;
  6.017  END
